(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6700,        189]*)
(*NotebookOutlinePosition[      7352,        212]*)
(*  CellTagsIndexPosition[      7308,        208]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["ASTROID\nASZTROIS",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  FontFamily->"Hu-Helvetica"],

Cell["\<\
A param\[EAcute]teres egyenlet\[EAcute]b\[OTilde]l megrajzolhatjuk az \
asztroist (ast).
Ha egy k\[ODoubleDot]rt (circ) g\[ODoubleDot]rd\[IAcute]t\[UDoubleDot]nk egy \
n\[EAcute]gyszer akkora \[AAcute]tm\[EAcute]r\[OTilde]j\[UHat] \
k\[ODoubleDot]r\[ODoubleDot]n bel\[UDoubleDot]l (circout), akkor a k\
\[ODoubleDot]r b\[AAcute]rmely pontja asztrois p\[AAcute]ly\[AAcute]n halad. \
A g\[ODoubleDot]rd\[IAcute]tett k\[ODoubleDot]rbe rajzoljuk be az egyik \
sugarat (line) \[EAcute]s a k\[ODoubleDot]r egy pontj\[AAcute]t (body). Az \
\[IAcute]gy l\[EAcute]trehozott egys\[EAcute]get (u) a Table funkci\[OAcute] \
seg\[IAcute]ts\[EAcute]g\[EAcute]vel helyezz\[UDoubleDot]k a g\[ODoubleDot]rd\
\[UDoubleDot]l\[OTilde] k\[ODoubleDot]r k\[ODoubleDot]z\[EAcute]ppontj\
\[AAcute]n \[AAcute]tmen\[OTilde] k\[ODoubleDot]r pontjaira egym\[AAcute]s ut\
\[AAcute]n 2Pi/n t\[AAcute]vols\[AAcute]gban. Minden l\[EAcute]p\[EAcute]sn\
\[EAcute]l forgassuk el az egys\[EAcute]get 2Pi/(n/3) sz\[ODoubleDot]ggel, \
ezzel a tengelye k\[ODoubleDot]r\[UDoubleDot]l h\[AAcute]romszor megforgatva \
a k\[ODoubleDot]rt egy k\[ODoubleDot]rbe g\[ODoubleDot]rd\[UDoubleDot]l\
\[EAcute]s alatt.
Astroid can be drawn with the help of its parametric equation (ast).
If a circle (circ) is rolled within another circle having four times as large \
diameter (circout), than any point of the rolled circle runs along an astroid \
curve. Let us now draw one radius (line) and one point (body) of the rolled \
circle. Place the unit (u) thus created on the pitch circle with 2Pi/n \
specing, while rotating the unit with an angle of 2Pi/(n/3) in each \
consecutive step. With this procedure the rolling circle is turned three \
times around its axis while rolling around once.\
\>", "Text",
  FontFamily->"Hu-Helvetica"],

Cell[BoxData[
    \(<< Graphics`Master`\)], "Input"],

Cell[BoxData[
    \(<< Graphics`Polyhedra`\)], "Input"],

Cell[BoxData[
    \(<< Graphics`Shapes`\)], "Input"],

Cell[BoxData[
    \(\(\(<< Graphics`Graphics3D`\)\(\ \)\)\)], "Input"],

Cell["<<Graphics`ParametricPlot3D`", "Input"],

Cell["ast=ParametricPlot3D[{Sin[x]^3, Cos[x]^3, 0},{x,-Pi,Pi}]", "Input"],

Cell["(*Egys\[EAcute]g sugar\[UAcute] k\[ODoubleDot]r*)", "Input"],

Cell["circ=ParametricPlot3D[{Sin[x],Cos[x],0},{x,-Pi,Pi}]", "Input"],

Cell[BoxData[
    \(circin = 
      Show[Graphics3D[
          TranslateShape[
            AffineShape[RotateShape[First[circ], 0, 0, 0], 2 {1, 1, 1}], {0, 
              0, 0}]]]\)], "Input",
  AnimationDisplayTime->0.2197],

Cell[BoxData[
    \(circroll = 
      Show[Graphics3D[
          TranslateShape[
            AffineShape[RotateShape[First[circ], 0, 0, 0], {1, 1, 1}], {3, 0, 
              0}], Boxed -> True, Axes -> True, FaceGrids -> All]]\)], "Input",\

  AnimationDisplayTime->0.2197],

Cell[BoxData[
    \(circout = 
      Show[Graphics3D[
          TranslateShape[
            AffineShape[RotateShape[First[circ], 0, 0, 0], 4 {1, 1, 1}], {0, 
              0, 0}], Boxed -> True]]\)], "Input",
  AnimationDisplayTime->0.2197],

Cell[BoxData[
    \(circpitch = 
      Show[Graphics3D[
          TranslateShape[
            AffineShape[RotateShape[First[circ], 0, 0, 0], 3 {1, 1, 1}], {0, 
              0, 0}], Boxed -> True]]\)], "Input",
  AnimationDisplayTime->0.2197],

Cell["circall=Show[circin,circroll,circout,circpitch,Axes->True]", "Input"],

Cell["(*A g\[ODoubleDot]rd\[UDoubleDot]l\[OTilde] k\[ODoubleDot]rre helyezett \
egys\[EAcute]g: u=line+body*)", "Input"],

Cell["v1={0,0,0}", "Input"],

Cell["v2={1,0,0}", "Input"],

Cell["\<\
lin=Show[Graphics3D[{RGBColor[0,1,0.2],Line/@{{
v1,v2
}}}],Boxed->False,Axes->True,ViewPoint->{0,0,10000}]\
\>", "Input"],

Cell["body0=Show[Graphics3D[Drop[Dodecahedron[],{2,12}]]]", "Input"],

Cell[BoxData[
    \(body1 = 
      Show[Graphics3D[
          Truncate[
            TranslateShape[
              AffineShape[RotateShape[First[body0], 0, 0, 0], 
                0.2 {1, 1, 1}], {1, 0, 1}], 0.3], Axes -> True]]\)], "Input",
  AnimationDisplayTime->0.2197],

Cell["u=Show[lin,body1]", "Input"],

Cell["u1=Show[lin,body1,circ]", "Input"],

Cell["n=100", "Input"],

Cell[BoxData[{
    \(\(Clear[g];\)\), "\n", 
    \(\tg[i_] := 
      Graphics3D[
        TranslateShape[
          AffineShape[
            RotateShape[First[u], 0, 0, \(-i\)*2  Pi/\((n/3)\)], {1, 1, 
              1}], \ 3 {Sin[i*2  Pi/n], Cos[i*2  Pi/n], 0}], 
        ViewPoint -> {0, 0, 3}, Boxed -> False, Axes -> True, 
        FaceGrids -> None]\)}], "Input"],

Cell[BoxData[
    \(fin = 
      Show[Table[g[i], {i, n}], Axes -> False, 
        LightSources -> \n\t\t{{{1, 0, 1}, 
              RGBColor[1, 0.1, 0.1]}, {{\(-1\), 1, 1}, 
              RGBColor[0.3, 1, 0.2]}, \n\t\t\t{{\(-1\), \(-1\), 1}, 
              RGBColor[0.2, 0.4, 0.9]}}]\)], "Input"],

Cell["aggr=Show[fin,circall]", "Input"]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 640}, {0, 407}},
WindowSize->{545, 344},
WindowMargins->{{0, Automatic}, {Automatic, 7}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 130, 3, 50, "Text"],
Cell[1850, 54, 1793, 27, 248, "Text"],
Cell[3646, 83, 52, 1, 30, "Input"],
Cell[3701, 86, 55, 1, 30, "Input"],
Cell[3759, 89, 52, 1, 30, "Input"],
Cell[3814, 92, 70, 1, 30, "Input"],
Cell[3887, 95, 45, 0, 30, "Input"],
Cell[3935, 97, 73, 0, 30, "Input"],
Cell[4011, 99, 66, 0, 30, "Input"],
Cell[4080, 101, 68, 0, 30, "Input"],
Cell[4151, 103, 224, 6, 110, "Input"],
Cell[4378, 111, 273, 7, 110, "Input"],
Cell[4654, 120, 240, 6, 110, "Input"],
Cell[4897, 128, 242, 6, 110, "Input"],
Cell[5142, 136, 75, 0, 30, "Input"],
Cell[5220, 138, 120, 1, 30, "Input"],
Cell[5343, 141, 27, 0, 30, "Input"],
Cell[5373, 143, 27, 0, 30, "Input"],
Cell[5403, 145, 131, 4, 66, "Input"],
Cell[5537, 151, 68, 0, 30, "Input"],
Cell[5608, 153, 272, 7, 130, "Input"],
Cell[5883, 162, 34, 0, 30, "Input"],
Cell[5920, 164, 40, 0, 30, "Input"],
Cell[5963, 166, 22, 0, 30, "Input"],
Cell[5988, 168, 366, 9, 170, "Input"],
Cell[6357, 179, 297, 6, 90, "Input"],
Cell[6657, 187, 39, 0, 30, "Input"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

