(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7435,        218]*)
(*NotebookOutlinePosition[      8150,        243]*)
(*  CellTagsIndexPosition[      8106,        239]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[
"ROLLING CIRCLES\n\
G\[CapitalODoubleDot]RD\[CapitalUDoubleDot]L\[CapitalOTilde] K\
\[CapitalODoubleDot]R\[CapitalODoubleDot]K",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  FontFamily->"Hu-Helvetica"],

Cell["\<\
\[CapitalAAcute]ltal\[AAcute]nos\[IAcute]tsuk az 58. leck\[EAcute]ben adott m\
\[OAcute]dszert \[UAcute]gy, hogy az egys\[EAcute]g sugar\[UAcute] k\
\[ODoubleDot]rt g\[ODoubleDot]rd\[IAcute]ts\[UDoubleDot]nk egy k sugar\
\[UAcute] k\[ODoubleDot]r\[ODoubleDot]n bel\[UDoubleDot]l. Egy \
k\[ODoubleDot]r megt\[EAcute]tele k\[ODoubleDot]zben a k\[ODoubleDot]r \
(k-1)-szer fordul k\[ODoubleDot]rbe saj\[AAcute]t tengelye k\[ODoubleDot]r\
\[UDoubleDot]l. A g\[ODoubleDot]rbe cs\[UAcute]csainak sz\[AAcute]ma k, \
\[EAcute]s k\[IAcute]v\[UDoubleDot]l helyzekendek el. 
Tov\[AAcute]bbi \[AAcute]ltal\[AAcute]nos\[IAcute]t\[AAcute]si \
lehet\[OTilde]s\[EAcute]g az, hogy az egys\[EAcute]g (u) forg\[AAcute]si ir\
\[AAcute]ny\[AAcute]t ellenkez\[OTilde]re v\[AAcute]ltjuk. Ezzel \
imit\[AAcute]lhatjuk azt az esetet, amikor a k\[ODoubleDot]rt \
g\[ODoubleDot]rd\[IAcute]tj\[UDoubleDot]k egy k-2 sugar\[UAcute] k\
\[ODoubleDot]r\[ODoubleDot]n k\[IAcute]v\[UDoubleDot]l. A g\[ODoubleDot]rbe \
cs\[UAcute]csainak sz\[AAcute]ma k-2, \[EAcute]s bel\[UDoubleDot]l \
helyezkednek el.

Let us generalise the procedure described in Lesson 58 by rolling a circle of \
unit radius within a circle of radius k. While completing a cycle the circle \
rotated around its own axis k-1 times. The number of vertices of the curve is \
k, and are outside.
A further possible generalisation allowed if the unit (u) is turned in the \
opposite direction. This is a simulation of a circle around anoather circle \
having a radius of k-2. The number of vertices of the curve is k-2 and are \
inside. \
\>", "Text",
  FontFamily->"Hu-Helvetica"],

Cell[BoxData[
    \(<< Graphics`Master`\)], "Input"],

Cell[BoxData[
    \(<< Graphics`Polyhedra`\)], "Input"],

Cell[BoxData[
    \(<< Graphics`Shapes`\)], "Input"],

Cell[BoxData[
    \(\(\(<< Graphics`Graphics3D`\)\(\ \)\)\)], "Input"],

Cell["<<Graphics`ParametricPlot3D`", "Input"],

Cell["\<\
El\[OTilde]zetes v\[AAcute]laszt\[AAcute]si lehet\[OTilde]s\[EAcute]gek: k =a \
k\[UDoubleDot]ls\[OTilde] k\[ODoubleDot]r \[AAcute]tm\[EAcute]r\[OTilde]je, n \
= az \[AAcute]rb\[AAcute]zolt l\[EAcute]p\[EAcute]sek sz\[AAcute]ma, turn = \
-1,ha az egys\[EAcute]g k\[ODoubleDot]r egy k\[ODoubleDot]r\[ODoubleDot]n bel\
\[UDoubleDot]l g\[ODoubleDot]rd\[UDoubleDot]l, turn =1, ha a k\[ODoubleDot]r \
egy k\[ODoubleDot]r\[ODoubleDot]n k\[IAcute]v\[OTilde]l g\[ODoubleDot]rd\
\[UDoubleDot]l.

Preliminary selections: k = diameter of external circle, n = nuber of steps \
depicted, turn = -1 for rolling inside a circle, turn = 1 for turning outside \
a circle.\
\>", "Text",
  FontFamily->"Hu-Helvetica"],

Cell["\<\
k=4;
n=200;
turn=-1;\
\>", "Input"],

Cell["circ=ParametricPlot3D[{Sin[x],Cos[x],0},{x,-Pi,Pi}]", "Input"],

Cell[BoxData[
    \(circin = 
      Show[Graphics3D[
          TranslateShape[
            AffineShape[
              RotateShape[First[circ], 0, 0, 0], \((k - 2)\) {1, 1, 1}], {0, 
              0, 0}]]]\)], "Input",
  AnimationDisplayTime->0.2197],

Cell[BoxData[
    \(circroll = 
      Show[Graphics3D[
          TranslateShape[
            AffineShape[
              RotateShape[First[circ], 0, 0, 0], {1, 1, 1}], {\((k - 1)\), 0, 
              0}], Boxed -> True, Axes -> True, FaceGrids -> All]]\)], "Input",\

  AnimationDisplayTime->0.2197],

Cell[BoxData[
    \(circout = 
      Show[Graphics3D[
          TranslateShape[
            AffineShape[RotateShape[First[circ], 0, 0, 0], k {1, 1, 1}], {0, 
              0, 0}], Boxed -> True]]\)], "Input",
  AnimationDisplayTime->0.2197],

Cell["circall=Show[circin,circroll,circout,Axes->True]", "Input"],

Cell["\<\
R\[ODoubleDot]gz\[IAcute]ts\[UDoubleDot]nk k\[UDoubleDot]l\[ODoubleDot]nf\
\[EAcute]le t\[AAcute]rgyakat a g\[ODoubleDot]rd\[UDoubleDot]l\[OTilde] k\
\[ODoubleDot]rh\[ODoubleDot]z; vonal pont, stb.
Let us attach various objects to the rolling circle: line point, etc.\
\>", "Text",
  FontFamily->"Hu-Helvetica"],

Cell["\<\
v1={2,0,0};
v2={-3,0,0};\
\>", "Input"],

Cell["\<\
lin=Show[Graphics3D[{RGBColor[0.2,0.4,0.4],Line/@{{
v1,v2
}}}],Boxed->False,Axes->True,ViewPoint->{0,0,10000}]\
\>", "Input"],

Cell["\<\
body1=Show[Graphics3D[{PointSize[.020],RGBColor[1,0,0],Point[{1,0,0}]},
    PlotRange\[Rule]All]]\
\>", "Input"],

Cell["\<\
body2=Show[Graphics3D[{PointSize[.005],RGBColor[0.8,0.1,1],Point[{-0.2,0,0}]},\

    PlotRange\[Rule]All]]\
\>", "Input"],

Cell["\<\
body3=Show[Graphics3D[{PointSize[.015],RGBColor[0.2,0.5,1],Point[{2,0,0}]},
    PlotRange\[Rule]All]]\
\>", "Input"],

Cell["\<\
body4=Show[Graphics3D[{PointSize[.015],RGBColor[0,1,0.5],Point[{-3,0,0}]},
    PlotRange\[Rule]All]]\
\>", "Input"],

Cell["u=Show[lin,body1,body2,body3,body4]", "Input"],

Cell["u1=Show[u,circ]", "Input"],

Cell[BoxData[{
    \(\(Clear[g];\)\), "\n", 
    \(\tg[i_] := 
      Graphics3D[
        TranslateShape[
          AffineShape[
            RotateShape[First[u], 0, 0, 
              turn*i*2  Pi/\((n/\((k - 1)\))\)], {1, 1, 
              1}], \ \((k - 1)\) {Sin[i*2  Pi/n], Cos[i*2  Pi/n], 0}], 
        ViewPoint -> {0, 0, 3}, Boxed -> False, Axes -> True, 
        FaceGrids -> None]\)}], "Input"],

Cell[BoxData[
    \(fin = 
      Show[Table[g[i], {i, n}], Axes -> False, 
        LightSources -> \n\t\t{{{1, 0, 1}, 
              RGBColor[1, 0.1, 0.1]}, {{\(-1\), 1, 1}, 
              RGBColor[0.3, 1, 0.2]}, \n\t\t\t{{\(-1\), \(-1\), 1}, 
              RGBColor[0.2, 0.4, 0.9]}}]\)], "Input"],

Cell["aggr=Show[fin,circall]", "Input"]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 640}, {0, 407}},
WindowSize->{563, 375},
WindowMargins->{{13, Automatic}, {1, Automatic}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 239, 6, 50, "Text"],
Cell[1959, 57, 1623, 27, 248, "Text"],
Cell[3585, 86, 52, 1, 30, "Input"],
Cell[3640, 89, 55, 1, 30, "Input"],
Cell[3698, 92, 52, 1, 30, "Input"],
Cell[3753, 95, 70, 1, 30, "Input"],
Cell[3826, 98, 45, 0, 30, "Input"],
Cell[3874, 100, 708, 13, 104, "Text"],
Cell[4585, 115, 45, 4, 66, "Input"],
Cell[4633, 121, 68, 0, 30, "Input"],
Cell[4704, 123, 249, 7, 110, "Input"],
Cell[4956, 132, 298, 8, 130, "Input"],
Cell[5257, 142, 240, 6, 110, "Input"],
Cell[5500, 150, 65, 0, 30, "Input"],
Cell[5568, 152, 321, 6, 50, "Text"],
Cell[5892, 160, 49, 3, 48, "Input"],
Cell[5944, 165, 135, 4, 66, "Input"],
Cell[6082, 171, 122, 3, 66, "Input"],
Cell[6207, 176, 131, 4, 66, "Input"],
Cell[6341, 182, 126, 3, 66, "Input"],
Cell[6470, 187, 125, 3, 66, "Input"],
Cell[6598, 192, 52, 0, 30, "Input"],
Cell[6653, 194, 32, 0, 30, "Input"],
Cell[6688, 196, 401, 10, 170, "Input"],
Cell[7092, 208, 297, 6, 90, "Input"],
Cell[7392, 216, 39, 0, 30, "Input"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

