(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5140,        147]*)
(*NotebookOutlinePosition[      5794,        170]*)
(*  CellTagsIndexPosition[      5750,        166]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["CSIGAL\[CapitalEAcute]PCS\[CapitalOTilde]\nSPIRAL \
STAIRCASE\n",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center,
  FontFamily->"Hu-Helvetica"],

Cell["\<\
K\[EAcute]sz\[IAcute]ts\[UDoubleDot]k el a l\[EAcute]pcs\[OTilde]fokot, pl. \
egy kocka torz\[IAcute]t\[AAcute]s\[AAcute]val (step). A korl\[AAcute]toszlop \
k\[EAcute]sz\[IAcute]t\[EAcute]s\[EAcute]hez is kiindulhatunk a \
kock\[AAcute]b\[OAcute]l (post). Legyen a k\[ODoubleDot]zponti tart\[OAcute] \
egy henger (cyl). Rakjunk \[ODoubleDot]ssze egy l\[EAcute]pcs\[OTilde]fokot \
\[EAcute]s egy oszlopot egy egys\[EAcute]g\[EAcute], \[EAcute]s ezt \
v\[IAcute]zszintes eltol\[AAcute]s ut\[AAcute]n sokszorozzuk meg folyamatos \
emel\[EAcute]ssel \[EAcute]s forgat\[AAcute]ssal. A kapott l\[EAcute]pcs\
\[OTilde]sort \[EAcute]p\[IAcute]ts\[UDoubleDot]k \[ODoubleDot]ssze a \
hengerrel. A korl\[AAcute]t elk\[EAcute]sz\[IAcute]t\[EAcute]s\[EAcute]re \
induljunk ki egy csavarvonalb\[OAcute]l (c), amit a \"rope\" seg\[IAcute]ts\
\[EAcute]g\[EAcute]vel megvastag\[IAcute]thatunk (rail), majd tegy\
\[UDoubleDot]k r\[AAcute] az oszlosorra. (A rope a Knife csomag \
r\[EAcute]sze).

Prepare a step, e.g. with the distortion of a cube (step). Cube may be also \
the basis for the rail post (post). Let us make the central support from a \
cylinder (cyl). After shifting in horizontal direction, multiply the unit by \
gradual rotation and moving upward. Create a helix (c). Thicken the helix \
with the \"rope\" function to produce the railing (rail), and  put the \
railing on the row of posts. (The rope is part of package Knife).\
\>", "Text",
  FontFamily->"Hu-Helvetica"],

Cell[BoxData[
    \(<< Graphics`Master`\)], "Input"],

Cell[BoxData[
    \(<< Graphics`Polyhedra`\)], "Input"],

Cell[BoxData[
    \(<< Graphics`Shapes`\)], "Input"],

Cell[BoxData[
    \(\(\(<< Graphics`Graphics3D`\)\(\ \)\)\)], "Input"],

Cell["<<Graphics`ParametricPlot3D`", "Input"],

Cell[BoxData[
    \(Get["\<knife`\>"]\)], "Input"],

Cell["cub=Graphics3D[Cube[]]", "Input"],

Cell["\<\
step=Show[Graphics3D[TranslateShape[AffineShape[RotateShape[First[cub],0,0,0],\
{5,2,0.2}],{6,0,0}],Boxed->False,Axes->True,FaceGrids->None]]\
\>", "Input"],

Cell["\<\
post=Graphics3D[TranslateShape[AffineShape[RotateShape[First[cub],0,0,0],0.1{\
1,1,40}],{9,0,3}]]\
\>", "Input"],

Cell[BoxData[
    \(step1 = Show[step, post, Axes \[Rule] False]\)], "Input"],

Cell["cyl= Show[Graphics3D[Cylinder[]]]", "Input"],

Cell["\<\
bar=Graphics3D[TranslateShape[AffineShape[RotateShape[First[cyl],0,0,0],2.5{1,\
1,8}],{0,0,20}],Boxed->False,Axes->True,FaceGrids->None]\
\>", "Input"],

Cell[BoxData[{
    \(\(Clear[b];\)\), "\n", 
    \(\tb[i_] := 
      Graphics3D[
        TranslateShape[
          AffineShape[
            RotateShape[First[step1], 0, 0, i*2  Pi/20], {1, 1, 1}], {0, 0, 
            1.3*i}], Boxed -> False]\)}], "Input"],

Cell[BoxData[
    \(stair = Show[Table[b[i], {i, 30}]]\)], "Input"],

Cell["Show[stair,bar]", "Input"],

Cell[BoxData[{
    \(\(c = {\ Sin[x\ ], \ Cos[x], \ x/2.46};\)\), "\n", 
    \(ParametricPlot3D[c, {x, 0, 3\ \[Pi]}]\)}], "Input"],

Cell[BoxData[
    \(rail = 
      rope[c, {x, 1.6, 3.6\ \[Pi]}, 0.03, 
        PlotPoints \[Rule] {10, 50}]\)], "Input"],

Cell[BoxData[
    \(rail1 = Show[AffineShape[rail, 10 {0.9, 0.9, 1}]]\)], "Input"],

Cell["t=Show[stair,bar,rail1,ViewPoint->{0,2,1},AmbientLight->Red]", "Input"]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 640}, {0, 407}},
WindowSize->{612, 358},
WindowMargins->{{Automatic, -1}, {Automatic, -5}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 176, 4, 68, "Text"],
Cell[1896, 55, 1481, 23, 194, "Text"],
Cell[3380, 80, 52, 1, 30, "Input"],
Cell[3435, 83, 55, 1, 30, "Input"],
Cell[3493, 86, 52, 1, 30, "Input"],
Cell[3548, 89, 70, 1, 30, "Input"],
Cell[3621, 92, 45, 0, 30, "Input"],
Cell[3669, 94, 50, 1, 30, "Input"],
Cell[3722, 97, 39, 0, 30, "Input"],
Cell[3764, 99, 166, 3, 48, "Input"],
Cell[3933, 104, 122, 3, 48, "Input"],
Cell[4058, 109, 77, 1, 30, "Input"],
Cell[4138, 112, 50, 0, 30, "Input"],
Cell[4191, 114, 161, 3, 48, "Input"],
Cell[4355, 119, 255, 7, 110, "Input"],
Cell[4613, 128, 67, 1, 30, "Input"],
Cell[4683, 131, 32, 0, 30, "Input"],
Cell[4718, 133, 130, 2, 50, "Input"],
Cell[4851, 137, 120, 3, 30, "Input"],
Cell[4974, 142, 82, 1, 30, "Input"],
Cell[5059, 145, 77, 0, 30, "Input"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

