(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5763,        169]*)
(*NotebookOutlinePosition[      6417,        192]*)
(*  CellTagsIndexPosition[      6373,        188]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["SPACE STRUCTURE WITH A CENTRAL CORE\n\
T\[CapitalEAcute]RSZERKEZET K\[CapitalODoubleDot]ZPONTI MAGGAL",
  TextAlignment->Center,
  FontFamily->"Hu-Helvetica",
  FontSize->14,
  FontWeight->"Bold"]], "Text",
  TextAlignment->Center],

Cell[TextData[{
  StyleBox["Tetsz\[OTilde]leges alak\[UAcute] poli\[EAcute]der (base) minden \
cs\[UAcute]cs\[AAcute]ra sug\[AAcute]rir\[AAcute]nyban \
\[AAcute]ll\[IAcute]tsunk egy rudat. A rudakat a \
k\[ODoubleDot]ss\[UDoubleDot]k \[ODoubleDot]ssze a a k\[IAcute]v\[AAcute]nt t\
\[AAcute]vols\[AAcute]gban.\nAz alapszerkezet lehet a ",
    FontFamily->"Hu-Helvetica"],
  StyleBox["Mathematica",
    FontFamily->"Hu-Helvetica",
    FontSlant->"Italic"],
  StyleBox[" \[AAcute]ltal felk\[IAcute]n\[AAcute]lt valamelyik \
szab\[AAcute]lyos poli\[EAcute]der ",
    FontFamily->"Hu-Helvetica"],
  "(Tetrahedron, Octahedron, Cube, Dodecahedron, Icosahedron, etc.),",
  StyleBox[" vagy a ",
    FontFamily->"Hu-Helvetica"],
  StyleBox["Mathematica",
    FontFamily->"Hu-Helvetica",
    FontSlant->"Italic"],
  StyleBox[" \[AAcute]ltal szerkeztett b\[AAcute]rmilyen konvex \
poli\[EAcute]der.\nA \"tr\" param\[EAcute]ter 0 \[EAcute]s 0.5 \
k\[ODoubleDot]z\[ODoubleDot]tt adhat\[OAcute] meg, amely a ",
    FontFamily->"Hu-Helvetica"],
  StyleBox["Mathematica",
    FontFamily->"Hu-Helvetica",
    FontSlant->"Italic"],
  StyleBox[" csonk\[IAcute]t\[AAcute]si funkci\[OAcute]j\[AAcute]nak felel \
meg. Ebben a szerkeszt\[EAcute]sben a k\[ODoubleDot]zponti mag \[EAcute]s a \
szerkezet k\[UDoubleDot]ls\[OTilde] \[AAcute]tm\[EAcute]r\[OTilde]je k\
\[ODoubleDot]z\[ODoubleDot]tti ar\[AAcute]nyt hat\[EAcute]rozza meg.\n\nA bar \
is inserted to every vertice of an arbitrary polyhedron in radial direction. \
The bars are interconnected at the requiered distance.\nThe basis of the \
structure is determined either by the name of the regular polyhedron offered \
by ",
    FontFamily->"Hu-Helvetica"],
  StyleBox["Mathematica ",
    FontFamily->"Hu-Helvetica",
    FontSlant->"Italic"],
  StyleBox["(Tetrahedron, Octahedron, Cube, Dodecahedron, Icosahedron, etc.), \
or can be any convex polyhedron constructed with ",
    FontFamily->"Hu-Helvetica"],
  StyleBox["Mathematica",
    FontFamily->"Hu-Helvetica",
    FontSlant->"Italic"],
  StyleBox[". \nParameter \"tr\" should be defined in the range from zero to \
0.5. In ",
    FontFamily->"Hu-Helvetica"],
  StyleBox["Mathematica",
    FontFamily->"Hu-Helvetica",
    FontSlant->"Italic"],
  StyleBox[" context this is the parameter of the \"Truncate\" function. In \
this package it determines the ratio of the central core to the outside \
diameter of the structutre.",
    FontFamily->"Hu-Helvetica"]
}], "Text"],

Cell[BoxData[
    \(<< Graphics`Polyhedra`\)], "Input"],

Cell[BoxData[
    \(<< Graphics`Shapes`\)], "Input"],

Cell[BoxData[
    \(\(\(<< Graphics`Graphics3D`\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(b0 = Cube\)], "Input"],

Cell[BoxData[
    \(tr = 0.35\)], "Input"],

Cell[BoxData[
    \(base = Show[Graphics3D[b0[]], Boxed \[Rule] False]\)], "Input"],

Cell[BoxData[
    \( (*Notice\ that\ base\ can\ be\ any\ other\ object*) \)], "Input"],

Cell[BoxData[
    \( (*base = Graphics3D[Truncate[Icosahedron[], 1/3]]*) \)], "Input"],

Cell[BoxData[
    \(b = 
      Graphics3D[{FaceForm[RGBColor[0.1, 1, 1], RGBColor[0.9, 0.2, 0.2]], 
          First[base]}]\)], "Input"],

Cell[BoxData[
    \(bshr = ShrinkPolygons[b, 0.99]\)], "Input"],

Cell[BoxData[
    \(bst = Stellate[bshr, 0]\)], "Input"],

Cell[BoxData[
    \(comb = Show[bshr, bst]\)], "Input"],

Cell[BoxData[
    \(trunc = Truncate[comb, tr]\)], "Input"],

Cell[BoxData[
    \(perf = PerforatePolygons[trunc, 0.9]\)], "Input"],

Cell[BoxData[
    \( (*outl = Show[OutlinePolygons[trunc, 0.98]]*) \)], "Input"],

Cell[BoxData[
    \(cent = 
      Graphics3D[{RGBColor[0.3, 0.3, 1], 
          AffineShape[First[base], 0.97  tr {1, 1, 1}]}]\)], "Input"],

Cell[BoxData[
    \(Show[perf, cent, Lighting \[Rule] False, 
      Boxed \[Rule] False]\)], "Input"]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 640}, {0, 407}},
WindowSize->{606, 371},
WindowMargins->{{Automatic, 1}, {-30, Automatic}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 255, 6, 56, "Text"],
Cell[1975, 57, 2459, 54, 286, "Text"],
Cell[4437, 113, 55, 1, 30, "Input"],
Cell[4495, 116, 52, 1, 30, "Input"],
Cell[4550, 119, 70, 1, 30, "Input"],
Cell[4623, 122, 42, 1, 30, "Input"],
Cell[4668, 125, 42, 1, 30, "Input"],
Cell[4713, 128, 83, 1, 30, "Input"],
Cell[4799, 131, 86, 1, 30, "Input"],
Cell[4888, 134, 86, 1, 30, "Input"],
Cell[4977, 137, 136, 3, 50, "Input"],
Cell[5116, 142, 63, 1, 30, "Input"],
Cell[5182, 145, 56, 1, 30, "Input"],
Cell[5241, 148, 55, 1, 30, "Input"],
Cell[5299, 151, 59, 1, 30, "Input"],
Cell[5361, 154, 69, 1, 30, "Input"],
Cell[5433, 157, 80, 1, 30, "Input"],
Cell[5516, 160, 139, 3, 70, "Input"],
Cell[5658, 165, 101, 2, 30, "Input"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

